@@ -8,8 +8,8 @@ def iterable_converged(left, right):
     Returns True, None if the two iterables generate identical, False, index otherwise.
     The index indicates the first position where the iterables differ
     """
-    for i, (l, r) in enumerate(zip_longest(left, right)):
-        if l != r:
+    for i, (l_item, r_item) in enumerate(zip_longest(left, right)):
+        if l_item != r_item:
             return False, i
     return True, None
 
@@ -34,8 +34,12 @@ class RestrictedFileSystemLoader(FileSystemLoader):
 
     @staticmethod
     def _ensure_not_unsafe_github(template):
-        if template.startswith(".github/") and not (template.endswith(".ght") or template.endswith(".j2")):
-            raise TemplateNotFound(f"Templates under the .github/ folder must end in .ght or j2: {template}")
+        if template.startswith(".github/") and not (
+            template.endswith(".ght") or template.endswith(".j2")
+        ):
+            raise TemplateNotFound(
+                f"Templates under the .github/ folder must end in .ght or j2: {template}"
+            )
 
     @staticmethod
     def _ensure_not_git(template):
